package com.ruoyi.app.service.impl;

import java.util.List;

import com.ruoyi.app.domain.AppWave;
import com.ruoyi.app.mapper.AppWaveMapper;
import com.ruoyi.app.service.IAppWaveService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 【请填写功能名称】Service业务层处理
 *
 * @author ruoyi
 * @date 2025-01-14
 */
@Service
public class AppWaveServiceImpl implements IAppWaveService
{
    @Autowired
    private AppWaveMapper appWaveMapper;

    /**
     * 查询【请填写功能名称】
     *
     * @param waveId 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    @Override
    public AppWave selectAppWaveByWaveId(String waveId)
    {
        return appWaveMapper.selectAppWaveByWaveId(waveId);
    }

    /**
     * 查询【请填写功能名称】列表
     *
     * @param appWave 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<AppWave> selectAppWaveList(AppWave appWave)
    {
        return appWaveMapper.selectAppWaveList(appWave);
    }

    /**
     * 新增【请填写功能名称】
     *
     * @param appWave 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertAppWave(AppWave appWave)
    {
        return appWaveMapper.insertAppWave(appWave);
    }

    /**
     * 修改【请填写功能名称】
     *
     * @param appWave 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateAppWave(AppWave appWave)
    {
        return appWaveMapper.updateAppWave(appWave);
    }

    /**
     * 批量删除【请填写功能名称】
     *
     * @param waveIds 需要删除的【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteAppWaveByWaveIds(String[] waveIds)
    {
        return appWaveMapper.deleteAppWaveByWaveIds(waveIds);
    }

    /**
     * 删除【请填写功能名称】信息
     *
     * @param waveId 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteAppWaveByWaveId(String waveId)
    {
        return appWaveMapper.deleteAppWaveByWaveId(waveId);
    }
}
