package com.ruoyi.web.controller.app;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.app.domain.AppVehicle;
import com.ruoyi.app.domain.AppWave;
import com.ruoyi.app.service.IAppWaveService;
import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.web.controller.section.EnhanceDataList;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 【请填写功能名称】Controller
 *
 * @author ruoyi
 * @date 2025-01-14
 */
@RestController
@RequestMapping("/app/wave")
public class AppWaveController extends BaseController
{
    @Autowired
    private IAppWaveService appWaveService;

    /**
     * 查询【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:wave:list')")
    @GetMapping("/list")
    @EnhanceDataList(entityType = AppWave.class)
    public TableDataInfo list(AppWave appWave)
    {
        startPage();
        List<AppWave> list = appWaveService.selectAppWaveList(appWave);
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:wave:export')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppWave appWave)
    {
        List<AppWave> list = appWaveService.selectAppWaveList(appWave);
        ExcelUtil<AppWave> util = new ExcelUtil<AppWave>(AppWave.class);
        util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:wave:query')")
    @GetMapping(value = "/{waveId}")
    public AjaxResult getInfo(@PathVariable("waveId") String waveId)
    {
        return success(appWaveService.selectAppWaveByWaveId(waveId));
    }

    /**
     * 新增【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:wave:add')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppWave appWave)
    {
        return toAjax(appWaveService.insertAppWave(appWave));
    }

    /**
     * 修改【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:wave:edit')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppWave appWave)
    {
        return toAjax(appWaveService.updateAppWave(appWave));
    }

    /**
     * 删除【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:wave:remove')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
    @DeleteMapping("/{waveIds}")
    public AjaxResult remove(@PathVariable String[] waveIds)
    {
        return toAjax(appWaveService.deleteAppWaveByWaveIds(waveIds));
    }

    /**
     * 下发波次任务
     */
//    @PreAuthorize("@ss.hasPermi('system:wave:add')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping("/executeWaves")
    @Anonymous
    public AjaxResult executeWaves(@RequestBody List<AppWave> appWaves)
    {
        return success();
    }
}
